@@ -14,7 +14,7 @@ const DEFAULT_LOG_FILE: &str = "hn-tui.log";
 use clap::*;
 use prelude::*;
 
-fn run(auth: Option<config::Auth>) {
+fn run(auth: Option<config::Auth>, start_id: Option<u32>) {
     // setup HN Client
     let client = client::init_client();
 
@@ -26,7 +26,7 @@ fn run(auth: Option<config::Auth>) {
     }
 
     // setup the application's UI
-    let s = view::init_ui(client);
+    let s = view::init_ui(client, start_id);
 
     // use `cursive_buffered_backend` crate to fix the flickering issue
     // when using `cursive` with `crossterm_backend` (See https://github.com/gyscos/Cursive/issues/142)
@@ -65,7 +65,7 @@ fn init_logging(log_dir_str: &str) {
 /// parse command line arguments
 fn parse_args(config_dir: std::path::PathBuf, cache_dir: std::path::PathBuf) -> ArgMatches {
     Command::new("hackernews-tui")
-        .version("0.12.0")
+        .version("0.13.1")
         .author("Thang Pham <phamducthang1234@gmail>")
         .about("A Terminal UI to browse Hacker News")
         .arg(
@@ -95,6 +95,13 @@ fn parse_args(config_dir: std::path::PathBuf, cache_dir: std::path::PathBuf) ->
                 .help("Path to a folder to store application's logs")
                 .next_line_help(true),
         )
+        .arg(
+            Arg::new("start_id")
+                .short('i')
+                .value_parser(clap::value_parser!(u32))
+                .help("The Hacker News item's id to start the application with")
+                .next_line_help(true),
+        )
         .get_matches()
 }
 
@@ -140,5 +147,6 @@ fn main() {
         args.get_one::<String>("auth")
             .expect("`auth` argument should have a default value"),
     );
-    run(auth);
+    let start_id = args.get_one::<u32>("start_id").cloned();
+    run(auth, start_id);
 }
